# Installing

## Python

If `sudo easy_install couchapp` doesn't work for you, you can install from source.

    git clone git://github.com/jchris/couchapp.git
    cd couchapp
    sudo python setup.py install

You may need to satisfy some dependencies. We hope this will happen automatically but... you never know.

## Questions and Comments

If you can improve this documentation, please send pull requests using Github or hit the [CouchApp mailing list](http://groups.google.com/group/couchapp). 

We want the install experience to go smoothly for **everyone**, so please send feedback and let us help you make this documentation cover troubleshooting problems.
